function [t,u]=euler1d(func,t0,a,y0,h)
% Eulerverfahren f"ur eindimensionale DGL
% input: func - Funktionsname (string)
%        t0   - Anfangspunkt unabh. Variable 
%        a    - L"ange des Intervalls
%        y0   - Anfangswert 
%        h    - Schrittweite (konstant)
% output:t    - Gitterpunkte unabh. Variable (Vektor)
%        u    - Werte N"aherungsl"osung (Vektor)
t(1)=t0;
u(1)=y0;
i=1;
while t(i)<t0+a-h
    t(i+1)=t(i)+h;
    u(i+1)=u(i)+h*feval(func,t(i),u(i));
    i=i+1;
end
% Schrittweite anpassen, um Intervallende genau zu treffen:
t(i+1)=t0+a;
u(i+1)=u(i)+(t(i+1)-t(i))*feval(func,t(i),u(i));

